# FluMutDb

<p align="center">
    <picture>
      <source media="(prefers-color-scheme: dark)" srcset=".github/images/flumut_logo_w.png">
      <source media="(prefers-color-scheme: light)" srcset=".github/images/flumut_logo_b.png">
      <img alt="FluMut logo." src=".github/images/flumut_logo_b.png">
    </picture>
</p>

[![GitHub Release](https://img.shields.io/github/v/release/izsvenezie-virology/FluMutDB?label=FluMutDB)](https://github.com/izsvenezie-virology/FluMutDB/releases/latest/)

FluMutDB contains all the data necessary to perform FluMut analysis.
You can find a complete list of all markers in [FluMut documentation](https://izsvenezie-virology.github.io/FluMut/docs/markers).

# Suggest new markers

To suggest us a new marker, open an [issue](https://github.com/izsvenezie-virology/FluMutDB/issues/new?assignees=&labels=&projects=&template=new-marker-request.md&title=).

In the issue you should report:

- the paper where the marker is described
- the mutations composing the marker
- the effect reported in the literature

## Cite FluMutDB

If you use FluMutDB, please cite:

> Giussani, E., Sartori, A. et al. (2025). FluMut: a tool for mutation surveillance in highly pathogenic H5N1 genomes. Virus Evolution, [10.1093/ve/veaf011](https://doi.org/10.1093/ve/veaf011).

# Fundings

This work was partially supported by the FLU-SWITCH Era-Net ICRAD (grant agreement No. 862605), by EU funding under the NextGeneration EU-MUR PNRR Extended Partnership initiative on Emerging Infectious Diseases (Project No. PE00000007, INF-ACT), and by KAPPA-FLU HORIZON-CL6-2022-FARM2FORK-02-03 (grant agreement No. 101084171).

<p align="center" margin="10px">
    <img style="height:80px;margin:8px" alt="Logo supporter, FLU-SWITCH" src=".github/images/Logo-Flu-Switch.png"/>
    <img style="height:80px;margin:8px" alt="Logo supporter, INF-ACT" src=".github/images/Logo-Inf-act.jpg"/>
    <img style="height:80px;margin:8px" alt="Logo supporter, European Union" src=".github/images/Logo-eu.png"/>
    <img style="height:80px;margin:8px" alt="Logo supporter, KAPPA-FLU" src=".github/images/logo-kappa-flu.jpg"/>
</p>

> Views and opinions expressed are however those of the author(s) only and do not necessarily reflect those of the European Union or the European Health and Digital Executive Agency (HEDEA).
> Neither the European Union nor the granting authority can be held responsible for them.
